@@ -53,6 +53,13 @@ class DecoratorMeta(abc.ABCMeta):
                     @Decorator[(...)]
                     def fun(self, *args, **kwargs)
 
+            x.4) classmethod
+                class ...
+                    @classmethod
+                    @Decorator[(...)]
+                    def fun(cls, *args, **kwargs)
+
+
         Note:
             To pass a single callable to init instead of wrapping it, add an Ellipsis (...)
         """
@@ -101,12 +108,16 @@ class DecoratorBase(metaclass=DecoratorMeta):
             -> args = 3
             -> kwargs = {'option': 24}
 
-    Additionally it can be applied to methods, function, staticmethods, ... without thinking.
-    Additionally functools.wraps is automatically applied to wrapped method. We recommend to
-    not use it in addition.
+    Additionally it can be applied to methods, function, staticmethods and classmethods without
+    thinking. Additionally functools.wraps is automatically applied to wrapped method. We
+    recommend to not use it in addition.
     """
 
     def __call__(self, *args, **kwargs):
+        """
+        Note:
+            `__call__` is called at different times for signatures 1 and 2.
+        """
         if self._func is None:
             # Signature 2
             assert len(args) == 1
@@ -125,7 +136,7 @@ class DecoratorBase(metaclass=DecoratorMeta):
         """
         if self._wrapped is None:
             if self._obj:
-                # Signature 2: _func is a method
+                # Signature 2.3: _func is a method
                 wrap = self._wrap_method(self._func)
                 wrap = functools.partial(wrap, self._obj)
                 wrap = functools.wraps(self._func)(wrap)
@@ -133,10 +144,16 @@ class DecoratorBase(metaclass=DecoratorMeta):
                 #       If you do not return here, you will always return the method of the
                 #       first object requested. That causes horror.
                 return wrap
-            elif "self" in inspect.Signature.from_callable(self._func).parameters:
-                # Signature 1: _func is a method but _obj is None
+            signature = inspect.Signature.from_callable(self._func)
+            first_arg_name = next(iter(signature.parameters), None)
+            if first_arg_name == "self":
+                # Signature 1.3: _func is a method but _obj is None
+                wrap = self._wrap_method(self._func)
+            elif first_arg_name == "cls":
+                # Signature x.3: _func is a classmethod
                 wrap = self._wrap_method(self._func)
             else:
+                # Signature x.1 / x.2
                 wrap = self._wrap_function(self._func)
             wrap = functools.wraps(self._func)(wrap)
             self._wrapped = wrap
@@ -159,7 +176,7 @@ class DecoratorBase(metaclass=DecoratorMeta):
     @abc.abstractmethod
     def _wrap_method(self, func):
         """
-        To implement for user
+        To implement for user. Function is method or classmethod (has one functional argument)
 
         Returns:
             callable: method
@@ -197,8 +214,9 @@ class Decorator(DecoratorBase):
         it needs to have.
 
         Args:
-            this: obj if func is method then 'this' corresponds to 'self' in the wrapped method.
-                if this is None, func is a function or staticmethod
+            this: obj if func is method or classmethod then 'this' corresponds to 'self' or 'cls'
+                in the wrapped method correspondingly.
+                If this is None, func is a function or staticmethod.
             func: func is the function to be wrapped and will be passed as an explicit kwarg
                 NOTE: When calling the function, do not use self as the first attribute even if
                 func is a method. This is handled internally.
