@@ -187,7 +187,10 @@ class Context:
         Returns:
             self._strategy: the newly instantiated strategy attribute.
         """
-        args, kwargs = self._strategy_init_values
+        (
+            args,
+            kwargs,
+        ) = self._strategy_init_values  # TODO use setters all over here. Why not?
         if self._strategy is None:
             if self.STRATEGY_DEFAULT is None:
                 return None
