@@ -83,11 +83,11 @@ class Writer(FFMPEGWRITER):
                 path = "/tmp/lastMovie.mp4"
             else:
                 path = rna.path.resolve(path)
-            log.info("Write movie to {path}".format(**locals()))
+            log.info("Write movie to %s", path)
             with super(Writer, self).saving(fig, path, dpi, **kwargs):
                 yield
         else:
-            log.warn("FFMPEG Writer not available. Nothing is written!")
+            log.warning("FFMPEG Writer not available. Nothing is written!")
 
 
 class set_zoomable(object):
@@ -224,7 +224,7 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
             axes.set_zlabel(labels[2])
         elif self.axes_dim(axes) != 2:
             raise ValueError(
-                "Axis dimensions other than 2 or 3 is not supported" "for set_labels."
+                "Axis dimensions other than 2 or 3 is not supported for set_labels."
             )
 
     @rna.plotting.plot_signature
@@ -360,9 +360,7 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
                 )
             )
             if os.path.exists(source):
-                log.warning(
-                    "I will copy the style {style} to {dest}.".format(**locals())
-                )
+                log.warning("I will copy the style %s to %s.", style, dest)
                 try:
                     self.upgrade_style(style, source, dest)
                     self.set_style(style)
@@ -370,10 +368,10 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
                     log.error("Could not set style")
             else:
                 log.error(
-                    "Could not set style {path}. Probably you would want to"
+                    "Could not set style %s. Probably you would want to"
                     "call rna.plotting.upgrade_style(<style>, "
                     "<path to mplstyle file that should be copied>)"
-                    "once".format(**locals())
+                    "once", path
                 )
 
     @contextlib.contextmanager
@@ -525,11 +523,8 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
             Artist or list of Artists (imitating the axes.scatter/plot behaviour).
             Better Artist not list of Artists
         """
-        import numpy as np
-
         xmin, xmax = kwargs.pop("xmin", 0), kwargs.pop("xmax", 1)
         num = kwargs.pop("num", 100)
-        np.linspace
         vals = np.linspace(xmin, xmax, num)
         args = (vals, map(fun, vals))
         artist = axes.plot(*args, **kwargs)
@@ -673,7 +668,7 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
             >>> artist = tm.plot(map=2, dim=2, color="r", linewidths=4)
             >>> rna.plotting.show()
         """
-        x_index, y_index, z_index = self.pop_xyz_index(kwargs)
+        x_index, y_index, _ = self.pop_xyz_index(kwargs)
         tensors = np.array(tensors)
         map_ = np.array(map_)
         if map_.shape[0] == 0:
@@ -702,6 +697,8 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
         """
         Args:
             axes (matplotlib axes)
+            vertices (np.ndarray): vertices of the mesh (shape: (n, 3))
+            faces (np.ndarray): faces of the mesh (indices of vertices) (shape: (m, 3))
             x_index (int)
             y_index (int)
             z_index (int)
@@ -726,6 +723,15 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
             import tfields
 
             mesh = tfields.Mesh3D(vertices, faces=faces)
+            transformation = np.eye(4)
+            transformation[:3, :3] = kwargs.pop("rotation", np.eye(3))
+            transformation[:3, 3] = kwargs.pop("translation", np.array([0, 0, 0]))
+
+            # rotation
+            mesh[:] = np.einsum("...i,t...i->t...", transformation[:3, :3], mesh)
+            # translation
+            mesh += transformation[:3, 3]
+
             facecolors = self.retrieve(
                 kwargs, "facecolors", "color", default=0, keep=False
             )
@@ -763,9 +769,7 @@ class ApiBackendMatplotlib(rna.plotting.ApiBackend):
 
             vertices = [mesh[:, x_index], mesh[:, y_index]]
 
-            """
-            sort out color arguments
-            """
+            # sort out color arguments
             facecolors = self.format_colors(
                 kwargs, facecolors, fmt="norm", length=n_faces_initial
             )
