@@ -25,7 +25,7 @@ def _get_axes_from_input(backend, *data, **kwargs):
         if dim != backend.axes_dim(axes):
             raise ValueError(
                 "Axes dimension and dim argument in conflict:"
-                "{backend.dim} vs {dim}".format(**locals())
+                f"{backend.dim} vs {dim}"
             )
     if axes is None:
         axes = backend.gca(dim=dim)
