@@ -5,7 +5,6 @@ import pathlib
 import typing
 import logging
 import io
-from six import string_types
 
 import rna.path
 
@@ -63,7 +62,7 @@ class Storable:
                 )
             return
 
-        if isinstance(path, (string_types, pathlib.Path)):
+        if isinstance(path, (str, pathlib.Path)):
             path = rna.path.resolve(path, *args)
             if extension is None:
                 extension = rna.path.extension(path)
@@ -113,7 +112,7 @@ class Storable:
                 extension (str): only needed if path is buffer
                 ... remaining:forwarded to extension specific method
         """
-        if isinstance(path, (string_types, pathlib.Path)):
+        if isinstance(path, (str, pathlib.Path)):
             # pylint: disable=possibly-unused-variable
             path = rna.path.resolve(path, *args)
             extension = kwargs.pop("extension", pathlib.Path(path).suffix.lstrip("."))
